<?php

class WPZpbwComments
{
	/**
	 * @var wpdb
	 */
	var $db;
	
	var $location;
	var $plugin_url;
	var $settings;
	
	var $o_settings;
	
	/**
	 * @return WPZpbwComments 
	 */
	function GetInstance()
	{
		static $instance;
		
		if(empty($instance))
			$instance = new WPZpbwComments;

		return $instance;
	}

	function WPZpbwComments()
	{
		global $wpdb, $table_prefix;

		$this->db = $wpdb;
		
		// remove path part of url
		$site_url = preg_replace('|^(https?://[^/]+)/?.*$|i', '$1', get_option('siteurl')); 
		
		$this->location = $site_url.$_SERVER['SCRIPT_NAME'];
		
		$this->plugin_url = WP_PLUGIN_URL.'/'.basename(dirname(__FILE__));
		
		// fill options names attributes
		foreach(get_object_vars($this) as $k=>$v)
		{
			if(preg_match('/^o_/i', $k))
				$this->$k = get_class($this).'_'.preg_replace('/^o_/i', '', $k);
		}
	}
	
	/**
	 * Hook for wordpress admin menu generation.
	 * Adds Comments settings link into Settings admin menu
	 * 
	 * @return null
	 */
	function add_pages()
	{
		global $user_level;
		get_currentuserinfo();
		
		if($user_level >= 8)
		{
			add_submenu_page('options-general.php', 'DiscussIt Comments', 'DiscussIt Comments', '0', 'DiscussIt-Comments', array($this, 'settings_page'));
		}
	}
	
	/**
	 * Filter comments template path.
	 * Change path to comments template if plugin active.
	 *  
	 * @param $path
	 * @return string
	 */
	function change_comments_template($path)
	{
		$settings = get_option($this->o_settings);

		if($settings['active'] == 'Y')
			return dirname(__FILE__).'/tpl/comments.php';
		else
			return $path;
			
	}
	
	/**
	 * Filter comments number string.
	 * Returns placeholder which will be replaced by javascript using API
	 * 
	 * @param $text
	 * @return unknown_type
	 */
	function fix_comments_number($text)
	{
		$settings = get_option($this->o_settings);
		
		global $post;

		if($settings['active'] == 'Y')
		{
			return '<span class="zpbw_comments_number post_id$['.$post->guid.']$" id="zpbw_post_id_'.$post->ID.'"></span>';
		}
		
		return $text;
	}
	
    /**
     * Hook for WP javascript including
     * Adds jquery and comments count replacer scripts. 
     * 
     * @return null
     */
    function add_js()
    {
		wp_enqueue_script('jquery');
    	wp_enqueue_script(get_class($this), $this->plugin_url.'/getPostsNoApi.js');
    }
    
    /**
     * Hook for WP page header generation
     * Adds API script loader code. 
     * 
     * @return null
     */
    function add_init_js()
    {
    	$settings = get_option($this->o_settings);
    	
    	$langNoComments = __("0");
    	$langOneComment = __("1");
    	$langNComments = __("%");
		
		if($settings['active'] == 'Y')
		{
    	
	    	echo <<<EOT
			<script type="text/javascript" language="javascript" id="zpbw_apiJs" src="http://www.pnyxe.com/PnyxeApiJs.jsp"></script>
	    	<script type="text/javascript">
	    		var zpbw_webWidgetClientKey = "{$settings['key']}";
	    		var zpbw_lang = {no_comments:"$langNoComments", one_comment:"$langOneComment", n_comments:"$langNComments"};
	    	</script>
EOT;
		}
    }
    
	/**
	 * Print settings page
	 * 
	 * @return unknown_type
	 */
    function settings_page()
	{
		$this->location .= "?page=DiscussIt-Comments";
		
		if($this->formAction())
			return;
			
		$this->settings = get_option($this->o_settings);

		require_once(dirname(__FILE__).'/tpl/settings.php');	
		
	}
	
	/**
	 * Handle settings form saving
	 * 
	 * @return bool
	 */
	function formAction()
	{
		if(empty($_POST['action']))
			return false;
			
		if($_POST['action'] == 'save_settings')
		{
			$settings = $_POST['settings'];
			
			update_option($this->o_settings, $settings);
		}
		
		wp_redirect($this->location);
		return true;
	}
	
	
	/**
	 * Generate and return comments code
	 * 
	 * @return string
	 */
	function commentsCode()
	{
		$set = get_option($this->o_settings);
		
		global $post;
		
		$pageUrl = $post->guid;

		
		$code =<<<EOT
		<script type="text/javascript" language="javascript">
			var zpbw_webWidgetArticleUrl = "{$pageUrl}";
		</script>
		<script type="text/javascript" language="javascript" id="pnyxeDiscussItJs" src="http://www.pnyxe.com/PnyxeDiscussItJs.jsp"></script>
		<script type="text/javascript" language="javascript" id="pnyxeDiscussItInitJs864783">try { var zpbw_webWidgetClientKey = "{$set['key']}"; var zpbw_webWidgetPlatform = "wordpress"; var pnyxeDiscussIt = new PnyxeDiscussIt(); pnyxeDiscussIt.init("864783"); } catch (e) {}</script>
		<noscript><a href="http://www.pnyxe.com/DiscussIt-comment-system?utm_source=wwcCodeSpanPromotionWordPress">WordPress Comment System</a></noscript>
EOT;

		$zpbw_url = "http://www.pnyxe.com/CrawlableHtmlService" .
			   "?webWidgetClientKey={$set['key']}" .
			   "&webWidgetClientPassword={$set['pass']}" .
			   "&webWidgetArticleUrl=" . urlencode($pageUrl) .
			   "&encoding=" . get_option('blog_charset') .
			   "&userAgent=" . urlencode($_SERVER['HTTP_USER_AGENT']);

		if (isset($_SERVER['HTTPS'])) {
		   $zpbw_implicitArticleUrl = 'https://';
		} else {
		   $zpbw_implicitArticleUrl = 'http://';
		}
		$zpbw_implicitArticleUrl .= $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
		$zpbw_url .= '&implicitArticleUrl=' . urlencode($zpbw_implicitArticleUrl);

		$code .= wp_remote_fopen($zpbw_url); 

		return $code;
	}
	
	/**
	 * Generate and return Recent Comments widget code
	 * 
	 * @param $instance
	 * @return unknown_type
	 */
	function recentCommentsCode($instance)
	{
		$set = get_option($this->o_settings);
		
		$code =<<<EOT
		<div>
			<script type="text/javascript" language="javascript" id="pnyxeRecentPostsJs" src="http://www.pnyxe.com/PnyxeRecentPostsJs.jsp"></script>
			<script type="text/javascript" language="javascript" id="pnyxeRecentPostsInitJs734059">try { var zpbw_recentPostsClientKey = "{$set['key']}"; var zpbw_recentPostsHeight = "{$instance['height']}"; var pnyxeRecentPosts = new PnyxeRecentPosts(); pnyxeRecentPosts.init("734059"); } catch (e) {}</script>
			<noscript><a href="http://www.pnyxe.com/DiscussIt-comment-system?utm_source=wwcCodeSpanPromotionWordPress">Comment System</a></noscript>
		</div>
EOT;
		return $code;
	}
	
}

/**
 * Generate callbacks for main class methods
 *
 */
class WPZpbwCommentsCB
{
	/**
	 * @return WPZpbwComments
	 */
	function GetInstance()
	{
		static $instance;

		if(empty($instance))
			$instance = new WPZpbwCommentsCB;

		return $instance;
	}
	
	function __call($method, $args)
	{
		$main = WPZpbwComments::GetInstance();
		
		if(method_exists($main, $method))
			return array($main, $method);
		else
			return false;
	}
}

?>